@@ -109,6 +109,12 @@ WARNING_TEXT_COLOR = parse_color("red")
 LARGE_MARKUP = u'<span size="x-large">%s</span>'
 
 
+# SSL properties and certs location
+STRICT_SSL_PROP = 'ssl-strict'
+CERTS_FILE_PROP = 'ssl-ca-file'
+CA_CERT_FILE = '/etc/ssl/certs/ca-certificates.crt'
+
+
 def log_call(f):
     """Decorator to log call funtions."""
 
@@ -539,11 +545,12 @@ class UbuntuSSOClientGUI(object):
 
         msg = YES_TO_UPDATES % {'app_name': self.app_name}
         self.yes_to_updates_checkbutton.set_label(msg)
-        if self.tc_url:
-            msg = YES_TO_TC % {'app_name': self.app_name}
-            self.yes_to_tc_checkbutton.set_label(msg)
-            self.tc_button.set_label(TC_BUTTON)
-        else:
+
+        msg = YES_TO_TC % {'app_name': self.app_name}
+        self.yes_to_tc_checkbutton.set_label(msg)
+        self.tc_button.set_label(TC_BUTTON)
+
+        if not self.tc_url:
             self.tc_vbox.hide()
         self.login_button.set_label(LOGIN_BUTTON_LABEL)
 
@@ -741,6 +748,7 @@ class UbuntuSSOClientGUI(object):
         name = self.name_entry.get_text()
         if not name:
             self.name_entry.set_warning(FIELD_REQUIRED)
+            logger.warning('on_join_ok_button_clicked: name not set.')
             error = True
 
         # check email
@@ -750,6 +758,7 @@ class UbuntuSSOClientGUI(object):
         if msg is not None:
             self.email1_entry.set_warning(msg)
             self.email2_entry.set_warning(msg)
+            logger.warning('on_join_ok_button_clicked: email is not valid.')
             error = True
 
         # check password
@@ -759,22 +768,30 @@ class UbuntuSSOClientGUI(object):
         if msg is not None:
             self.password1_entry.set_warning(msg)
             self.password2_entry.set_warning(msg)
+            logger.warning('on_join_ok_button_clicked: password is not valid.')
             error = True
 
         # check T&C
-        if not self.yes_to_tc_checkbutton.get_active():
+        if self.tc_url and not self.yes_to_tc_checkbutton.get_active():
             self._set_warning_message(self.tc_warning_label,
                 TC_NOT_ACCEPTED % {'app_name': self.app_name})
+            logger.warning('on_join_ok_button_clicked: terms and conditions '
+                           'not accepted.')
             error = True
 
         captcha_solution = self.captcha_solution_entry.get_text()
         if not captcha_solution:
             self.captcha_solution_entry.set_warning(FIELD_REQUIRED)
+            logger.warning('on_join_ok_button_clicked: captcha solution not '
+                           'set.')
             error = True
 
         if error:
+            logger.warning('on_join_ok_button_clicked: validation failed.')
             return
 
+        logger.info('on_join_ok_button_clicked: validation success!')
+
         self._set_current_page(self.processing_vbox)
         self.user_email = email1
         self.user_password = password1
@@ -942,11 +959,23 @@ class UbuntuSSOClientGUI(object):
 
         self._set_current_page(self.processing_vbox)
 
+    def _webkit_init_ssl(self):
+        """Set the WebKit ssl strictness."""
+        # delay the import of webkit to be able to build without it
+        from gi.repository import WebKit  # pylint: disable=E0611
+
+        # Set the Soup session to be strict and use system CA certs
+        session = WebKit.get_default_session()
+        session.set_property(STRICT_SSL_PROP, True)
+        session.set_property(CERTS_FILE_PROP, CA_CERT_FILE)
+
     def _add_webkit_browser(self):
         """Add the webkit browser for the t&c."""
         # delay the import of webkit to be able to build without it
         from gi.repository import WebKit  # pylint: disable=E0611
 
+        self._webkit_init_ssl()
+
         browser = WebKit.WebView()
 
         browser.connect('notify::load-status',
