@@ -473,8 +473,9 @@ class UbuntuSSOClientTestCase(BasicTestCase):
         # match passwords
         self.ui.password1_entry.set_text(PASSWORD)
         self.ui.password2_entry.set_text(PASSWORD)
-        # agree to TC
-        self.ui.yes_to_tc_checkbutton.set_active(True)
+        if self.ui.tc_url:
+            # agree to TC, only if the tc_url is defined, so we catch errors
+            self.ui.yes_to_tc_checkbutton.set_active(True)
         # resolve captcha properly
         self.ui.captcha_solution_entry.set_text(CAPTCHA_SOLUTION)
 
@@ -694,15 +695,15 @@ class EnterDetailsTestCase(UbuntuSSOClientTestCase):
         self.assertEqual(expected, actual,
                          msg % ('yes_to_tc_checkbutton', expected, actual))
 
-    def test_checkbutton_is_checked_at_startup(self):
-        """Checkbuttons are checked by default."""
+    def test_updates_checkbutton_is_checked_at_startup(self):
+        """The 'yes to updates' checkbutton is checked by default."""
         msg = '%r is checked by default.'
         name = 'yes_to_updates_checkbutton'
         widget = getattr(self.ui, name)
         self.assertTrue(widget.get_active(), msg % name)
 
-    def test_checkbutton_isnt_checked_at_startup(self):
-        """Checkbuttons are checked by default."""
+    def test_tc_checkbutton_is_not_checked_at_startup(self):
+        """The 'yes to T&C' checkbutton is not checked by default."""
         msg = '%r is checked by default.'
         name = 'yes_to_tc_checkbutton'
         widget = getattr(self.ui, name)
@@ -887,26 +888,22 @@ class EnterDetailsTestCase(UbuntuSSOClientTestCase):
         self.ui.on_captcha_generated(app_name=APP_NAME, captcha_id=CAPTCHA_ID)
         self.assertEqual(self.ui.warning_label.get_text().decode('utf8'), '')
 
-
-class NoTermsAndConditionsTestCase(UbuntuSSOClientTestCase):
-    """Test suite for the user registration (with no t&c link)."""
-
-    kwargs = dict(app_name=APP_NAME, tc_url='', help_text=HELP_TEXT)
-
-    def test_no_tc_link(self):
-        """The T&C button and checkbox are not shown if no link is provided"""
-        self.assertEqual(self.ui.tc_vbox.get_visible(), False)
-
-
-class TermsAndConditionsTestCase(UbuntuSSOClientTestCase):
-    """Test suite for the user registration (terms & conditions page)."""
-
     def test_has_tc_link(self):
         """The T&C button and checkbox are shown if the link is provided"""
         self.assertEqual(self.ui.tc_button.get_visible(), True)
         self.assertEqual(self.ui.yes_to_tc_checkbutton.get_visible(), True)
 
 
+class NoTermsAndConditionsTestCase(EnterDetailsTestCase):
+    """Test suite for the user registration (with no t&c link)."""
+
+    kwargs = dict(app_name=APP_NAME, tc_url='', help_text=HELP_TEXT)
+
+    def test_has_tc_link(self):
+        """The T&C button and checkbox are not shown if no link is provided"""
+        self.assertEqual(self.ui.tc_vbox.get_visible(), False)
+
+
 class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
     """Test suite for the terms & conditions browser."""
 
@@ -914,6 +911,7 @@ class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
     def setUp(self):
         yield super(TermsAndConditionsBrowserTestCase, self).setUp()
         self.patch(WebKit, 'WebView', FakedEmbeddedBrowser)
+        self.patch(self.ui, '_webkit_init_ssl', self._set_called)
 
         self.ui.tc_button.clicked()
         self.addCleanup(self.ui.tc_browser_vbox.hide)
@@ -922,6 +920,12 @@ class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
         assert len(children) == 1
         self.browser = children[0]
 
+    def test_ssl_validation(self):
+        """The browser is set to validate SSL."""
+        self.assertEqual(self._called, ((), {}),
+                         '_webkit_init_ssl should be called when creating a '
+                         'webkit browser.')
+
     def test_tc_browser_is_created_when_tc_page_is_shown(self):
         """The browser is created when the TC button is clicked."""
         self.ui.on_tc_browser_notify_load_status(self.browser)
