@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 #
-# test_keyring - tests for ubuntu_sso.keyring
+# test_linux - tests for ubuntu_sso.keyring under linux
 #
 # Author: Alejandro J. Cura <alecu@canonical.com>
 # Author: Natalia B. Bidart <natalia.bidart@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -18,22 +18,27 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the keyring.py module."""
 
-import socket
-
 from twisted.internet import defer
 from twisted.internet.defer import inlineCallbacks
 from twisted.trial.unittest import TestCase
 
 from ubuntu_sso import keyring as common_keyring
 from ubuntu_sso.keyring import linux as keyring
-from ubuntu_sso.tests import APP_NAME
-
-
-def build_fake_gethostname(fake_hostname):
-    """Return a fake hostname getter."""
-    return lambda *a: fake_hostname
 
 
 class MockItem(object):
@@ -116,43 +121,6 @@ class MockSecretService(object):
         return defer.succeed(self.collections["default"])
 
 
-class TestTokenNameBuilder(TestCase):
-    """Test the method that builds the token name."""
-
-    def test_get_simple_token_name(self):
-        """A simple token name is built right."""
-        sample_app_name = "UbuntuTwo"
-        sample_hostname = "Darkstar"
-        expected_result = "UbuntuTwo @ Darkstar"
-
-        fake_gethostname = build_fake_gethostname(sample_hostname)
-        self.patch(socket, "gethostname", fake_gethostname)
-        result = keyring.get_token_name(sample_app_name)
-        self.assertEqual(result, expected_result)
-
-    def test_get_complex_token_name_for_app_name(self):
-        """A complex token name is built right too."""
-        sample_app_name = "Ubuntu @ Eleven"
-        sample_hostname = "Mate+Cocido"
-        expected_result = "Ubuntu @ Eleven @ Mate+Cocido"
-
-        fake_gethostname = build_fake_gethostname(sample_hostname)
-        self.patch(socket, "gethostname", fake_gethostname)
-        result = keyring.get_token_name(sample_app_name)
-        self.assertEqual(result, expected_result)
-
-    def test_get_complex_token_name_for_hostname(self):
-        """A complex token name is built right too."""
-        sample_app_name = "Ubuntu Eleven"
-        sample_hostname = "Mate @ Cocido"
-        expected_result = "Ubuntu Eleven @ Mate AT Cocido"
-
-        fake_gethostname = build_fake_gethostname(sample_hostname)
-        self.patch(socket, "gethostname", fake_gethostname)
-        result = keyring.get_token_name(sample_app_name)
-        self.assertEqual(result, expected_result)
-
-
 class TestKeyring(TestCase):
     """Test the keyring related functions."""
 
@@ -165,8 +133,7 @@ class TestKeyring(TestCase):
         self.mock_service = None
         self.service = self.patch(keyring, "SecretService",
                                   self.get_mock_service)
-        fake_gethostname = build_fake_gethostname("darkstar")
-        self.patch(socket, "gethostname", fake_gethostname)
+        self.patch(common_keyring, "gethostname", lambda: u"darkstar")
 
     def get_mock_service(self):
         """Create only one instance of the mock service per test."""
@@ -213,9 +180,9 @@ class TestKeyring(TestCase):
         sample_creds = {"name": "sample creds name"}
         kr = keyring.Keyring()
         self.patch(keyring, "get_token_name", keyring.get_old_token_name)
-        yield kr.set_credentials(APP_NAME, sample_creds)
+        yield kr.set_credentials("app name", sample_creds)
 
-        result = yield kr.get_credentials(APP_NAME)
+        result = yield kr.get_credentials("app name")
         self.assertEqual(result, sample_creds)
 
     @inlineCallbacks
