@@ -342,10 +342,15 @@ class UbuntuSSOProxy(object):
 
     def __init__(self, root):
         self.root = root
-        self.bus = dbus.SessionBus()
         self.sso_login = None
         self.cred_manager = None
 
+        try:
+            self.bus = dbus.SessionBus()
+        except dbus.service.DBusException as e:
+            logger.exception(e)
+            shutdown_func()
+
     def start(self):
         """Start listening, nothing async to be done in this platform."""
         # Register DBus service for making sure we run only one instance
