@@ -37,7 +37,7 @@ from ubuntuone.devtools.handlers import MementoHandler
 
 import ubuntu_sso.main
 
-from ubuntu_sso import credentials, utils
+from ubuntu_sso import credentials
 from ubuntu_sso.credentials import (
     APP_NAME_KEY,
     HELP_TEXT_KEY,
@@ -111,6 +111,8 @@ class FakedSSOLogin(object):
 class BasicTestCase(TestCase):
     """Test case with a helper tracker."""
 
+    bin_dir = 'some/bin/dir'
+
     @defer.inlineCallbacks
     def setUp(self):
         """Init."""
@@ -121,6 +123,8 @@ class BasicTestCase(TestCase):
         self.memento.setLevel(logging.DEBUG)
         credentials.logger.addHandler(self.memento)
 
+        self.patch(credentials, 'get_bin_dir', lambda: self.bin_dir)
+
     def _set_called(self, *args, **kwargs):
         """Set _called to True."""
         self._called = (args, kwargs)
@@ -285,8 +289,7 @@ class RegisterTestCase(CredentialsTestCase):
         yield super(RegisterTestCase, self).setUp()
         self.deferred = defer.Deferred()
         self.patch_inner(self.fake_inner)
-        self.exe_path = os.path.join(utils.get_bin_dir(),
-                                     KWARGS[UI_EXECUTABLE_KEY])
+        self.exe_path = os.path.join(self.bin_dir, KWARGS[UI_EXECUTABLE_KEY])
         self.inner_args = [
             self.exe_path,
             '--app_name', APP_NAME,
@@ -347,11 +350,9 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_SUCCESS
 
-        # patch os.path.exists so it also returns True when queried for the
-        # faked exe_path
-        really_exists = os.path.exists
+        # patch os.path.exists so it returns True for the faked exe_path
         self.patch(credentials.os.path, 'exists',
-                   lambda path: path == self.exe_path or really_exists(path))
+                   lambda path: path == self.exe_path)
 
         result = yield self.method_call(**self.kwargs)
         self.assertEqual(result, TOKEN)
@@ -368,16 +369,47 @@ class RegisterTestCase(CredentialsTestCase):
         self._next_inner_result = credentials.USER_SUCCESS
 
         assert not os.path.exists(self.exe_path)
+        self.patch(credentials.os.path, 'exists',
+                   lambda path: path.endswith(credentials.UI_EXECUTABLE_GTK))
 
         result = yield self.method_call(**self.kwargs)
         self.assertEqual(result, TOKEN)
 
         # the ui was opened and proper params were passed
         args = yield self.deferred
-        self.inner_args[0] = os.path.join(utils.get_bin_dir(),
+        self.inner_args[0] = os.path.join(self.bin_dir,
                                           credentials.UI_EXECUTABLE_GTK)
         self.assertEqual(self.inner_args, args)
 
+    @defer.inlineCallbacks
+    def test_ui_executable_uses_qt_ui_if_gtk_not_available(self):
+        """The executable loads the QT UI if the GTK+ does not exist."""
+        self.patch(credentials.Keyring, 'get_credentials',
+                   lambda kr, app: defer.succeed(None))
+        self._next_inner_result = credentials.USER_SUCCESS
+
+        self.patch(credentials.os.path, 'exists',
+                   lambda path: path.endswith(credentials.UI_EXECUTABLE_QT))
+
+        result = yield self.method_call(**self.kwargs)
+        self.assertEqual(result, TOKEN)
+
+        # the ui was opened and proper params were passed
+        args = yield self.deferred
+        self.inner_args[0] = os.path.join(self.bin_dir,
+                                          credentials.UI_EXECUTABLE_QT)
+        self.assertEqual(self.inner_args, args)
+
+    @defer.inlineCallbacks
+    def test_raises_exception_if_no_ui_available(self):
+        """If no GUI is available, raise GUINotAvailableError."""
+        self.patch(credentials.Keyring, 'get_credentials',
+                   lambda kr, app: defer.succeed(None))
+        self.patch(credentials.os.path, 'exists', lambda path: False)
+
+        f = self.method_call(**self.kwargs)
+        yield self.assertFailure(f, credentials.GUINotAvailableError)
+
     @defer.inlineCallbacks
     def test_without_existent_token_and_return_code_cancel(self, exc=None):
         """The operation returns exc if defined, else UserCancellationError."""
@@ -385,17 +417,23 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_CANCELLATION
 
+        self.patch(credentials.os.path, 'exists',
+                   lambda path: path == self.exe_path)
+
         if exc is None:
             exc = credentials.UserCancellationError
         yield self.assertFailure(self.method_call(**self.kwargs), exc)
 
     @defer.inlineCallbacks
-    def test_without_existent_token_and_return_other(self, result=None):
+    def test_without_existent_token_and_return_other_code(self, result=None):
         """The operation returns CredentialsError with 'result'."""
         self.patch(credentials.Keyring, 'get_credentials',
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_CANCELLATION * 2  # other
 
+        self.patch(credentials.os.path, 'exists',
+                   lambda path: path == self.exe_path)
+
         exc = yield self.assertFailure(self.method_call(**self.kwargs),
                                        credentials.CredentialsError)
         if result is None:
@@ -422,6 +460,9 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self.patch_inner(self.fail_inner)
 
+        self.patch(credentials.os.path, 'exists',
+                   lambda path: path == self.exe_path)
+
         yield self.assertFailure(self.method_call(**self.kwargs),
                                  SampleMiscException)
 
@@ -478,14 +519,20 @@ class LoginEmailPasswordTestCase(RegisterTestCase):
     def test_ui_executable_falls_back_to_gtk(self):
         """This check does not apply for this test case."""
 
+    def test_ui_executable_uses_qt_ui_if_gtk_not_available(self):
+        """This check does not apply for this test case."""
+
+    def test_raises_exception_if_no_ui_available(self):
+        """This check does not apply for this test case."""
+
     def test_without_existent_token_and_return_code_cancel(self, exc=None):
         """The operation returns UserNotValidatedError."""
         exc = credentials.UserNotValidatedError
         return super(LoginEmailPasswordTestCase, self).\
                test_without_existent_token_and_return_code_cancel(exc=exc)
 
-    def test_without_existent_token_and_return_other(self, result=None):
+    def test_without_existent_token_and_return_other_code(self, result=None):
         """The operation returns CredentialsError with 'result'."""
         result = 'foo'
         return super(LoginEmailPasswordTestCase, self).\
-               test_without_existent_token_and_return_other(result=result)
+               test_without_existent_token_and_return_other_code(result=result)
