@@ -2,7 +2,7 @@
 
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the tcpactivation module."""
 
 # twisted uses a different coding convention
@@ -51,12 +63,25 @@ class FakeServerProtocol(protocol.Protocol):
         """Echo the data received."""
         self.transport.write(data)
 
+    #pylint:disable=E1101
+    def connectionLost(self, *a):
+        self.factory.onConnectionLost.callback(self)
+    #pylint:enable=E1101
+
 
 class FakeServerFactory(protocol.Factory):
     """A factory for the test server."""
 
     protocol = FakeServerProtocol
 
+    #pylint:disable=W0201
+    def __init__(self, testcase=None):
+        """Create a new instance for the testcase."""
+        if testcase is not None:
+            self.onConnectionLost = defer.Deferred()
+            testcase.addCleanup(lambda: self.onConnectionLost)
+    #pylint:enable=W0201
+
 
 class FakeTransport(object):
     """A fake transport."""
@@ -197,7 +222,7 @@ class ActivationDetectorTestCase(TestCase):
     @defer.inlineCallbacks
     def test_is_already_running(self):
         """The is_already_running method returns True if already started."""
-        f = FakeServerFactory()
+        f = FakeServerFactory(self)
         # pylint: disable=E1101
         listener = reactor.listenTCP(SAMPLE_PORT, f,
                                      interface=tcpactivation.LOCALHOST)
@@ -319,18 +344,20 @@ class ActivationInstanceTestCase(TestCase):
         port = yield ai.get_port()
         self.assertEqual(port, SAMPLE_PORT)
 
+    #pylint:disable=W0201
     @defer.inlineCallbacks
     def test_get_port_fails_if_service_already_started(self):
         """The get_port method fails if service already started."""
         ai1 = ActivationInstance(self.config)
         port1 = yield ai1.get_port()
-        f = FakeServerFactory()
+        f = FakeServerFactory(self)
         # pylint: disable=E1101
         listener = reactor.listenTCP(port1, f,
                                      interface=tcpactivation.LOCALHOST)
         self.addCleanup(listener.stopListening)
         ai2 = ActivationInstance(self.config)
         yield self.assertFailure(ai2.get_port(), AlreadyStartedError)
+    #pylint:enable=W0201
 
 
 def server_test(config):
