@@ -2,7 +2,7 @@
 
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,27 +15,28 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """
 Provides a twisted interface to access the system keyring via DBus.
 Implements the Secrets Service API Draft:
  * http://code.confuego.org/secrets-xdg-specs/
 """
 
-import sys
-# pylint: disable=E0611
-if 'gobject' in sys.modules:
-    import gobject as GObject
-else:
-    from gi.repository import GObject
-# pylint: enable=E0611
 import dbus
-from dbus.mainloop.glib import DBusGMainLoop
-import dbus.mainloop.glib
-from twisted.internet.defer import Deferred
 
-GObject.threads_init()
-dbus.mainloop.glib.threads_init()
-DBusGMainLoop(set_as_default=True)
+from twisted.internet.defer import Deferred
 
 BUS_NAME = "org.freedesktop.secrets"
 SERVICE_IFACE = "org.freedesktop.Secret.Service"
